package Task::Lingua::Any::Numbers;
$Task::Lingua::Any::Numbers::VERSION = '0.20';
use strict;
use warnings;

1;

__END__

=pod

=encoding UTF-8

=head1 NAME

Task::Lingua::Any::Numbers

=head1 VERSION

version 0.20

=head1 SYNOPSIS

None.

=head1 DESCRIPTION

This is a tool to install everything needed for a full L<Lingua::Any::Numbers>
interface. See the L<Task> module for the rationale.

=head1 NAME

Task::Lingua::Any::Numbers - Installs all number to word modules.

=head1 PREREQUISITIES

   Lingua::AF::Numbers
   Lingua::BG::Numbers
   Lingua::EN::Numbers
   Lingua::EU::Numbers
   Lingua::FR::Numbers
   Lingua::HU::Numbers
   Lingua::IT::Numbers
   Lingua::JA::Numbers
   Lingua::NL::Numbers
   Lingua::PL::Numbers
   Lingua::SV::Numbers
   Lingua::TR::Numbers
   Lingua::ZH::Numbers
   Lingua::CS::Num2Word
   Lingua::DE::Num2Word
   Lingua::ES::Numeros
   Lingua::ID::Nums2Words
   Lingua::NO::Num2Word
   Lingua::PT::Nums2Word
   Lingua::PT::Nums2Ords
   Lingua::Any::Numbers

=head1 SEE ALSO

L<Lingua::Any::Numbers>, L<Task>.

=head1 AUTHOR

Burak Gursoy <burak@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2009 by Burak Gursoy.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
